"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * @file For plugin to collect mnist data
 */
const pipcook_core_1 = require("@pipcook/pipcook-core");
const tf = __importStar(require("@tensorflow/tfjs-node"));
const jimp_1 = __importDefault(require("jimp"));
const path = __importStar(require("path"));
const xml2js = require('xml2js');
const fs = require('fs-extra');
const _cliProgress = require('cli-progress');
const mnist = require('mnist');
/**
 * collect mnist data
 */
const imageMnistDataCollect = (args) => __awaiter(void 0, void 0, void 0, function* () {
    const { savePath = process.cwd(), trainingCount = 4000, testCount = 500 } = args || {};
    const set = mnist.set(trainingCount, testCount);
    const trainingSet = set.training;
    const testSet = set.test;
    const bar1 = new _cliProgress.SingleBar({}, _cliProgress.Presets.shades_classic);
    console.log('collecting training data ...');
    bar1.start(trainingCount, 0);
    const saveDir = path.join(savePath, 'samples' + Date.now());
    for (let i = 0; i < trainingSet.length; i++) {
        bar1.update(i);
        const trainingSample = trainingSet[i];
        const input = (trainingSample.input).map((x) => x * 255);
        const output = trainingSample.output;
        const imageDir = path.join(saveDir, 'images');
        const annotationDir = path.join(saveDir, 'train');
        pipcook_core_1.createAnnotationFile(annotationDir, `trainsample${i}.jpg`, imageDir, String(output.indexOf(1)));
        fs.ensureDirSync(imageDir);
        const image = yield tf.node.encodeJpeg(tf.tensor3d(input, [28, 28, 1], 'int32'));
        const jimpImage = yield jimp_1.default.read(image.buffer);
        yield jimpImage.write(path.join(imageDir, `trainsample${i}.jpg`));
    }
    bar1.stop();
    console.log('collecting test data ...');
    const bar2 = new _cliProgress.SingleBar({}, _cliProgress.Presets.shades_classic);
    bar2.start(testCount, 0);
    for (let i = 0; i < testSet.length; i++) {
        bar2.update(i);
        const trainingSample = testSet[i];
        const input = (trainingSample.input).map((x) => x * 255);
        const output = trainingSample.output;
        const imageDir = path.join(saveDir, 'images');
        const annotationDir = path.join(saveDir, 'test');
        pipcook_core_1.createAnnotationFile(annotationDir, `testsample${i}.jpg`, imageDir, String(output.indexOf(1)));
        fs.ensureDirSync(imageDir);
        const image = yield tf.node.encodeJpeg(tf.tensor3d(input, [28, 28, 1], 'int32'));
        const jimpImage = yield jimp_1.default.read(image.buffer);
        yield jimpImage.write(path.join(imageDir, `testsample${i}.jpg`));
    }
    bar2.stop();
    const result = {
        trainDataPath: path.join(saveDir, 'train'),
        testDataPath: path.join(saveDir, 'test'),
    };
    return result;
});
exports.default = imageMnistDataCollect;
